You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@clerezza.apache.org by re...@apache.org on 2015/05/18 13:41:16 UTC

[1/2] clerezza git commit: removed duplicated dependency

Repository: clerezza
Updated Branches:
  refs/heads/master dacd8c71c -> fe6530be7


removed duplicated dependency

Project: http://git-wip-us.apache.org/repos/asf/clerezza/repo
Commit: http://git-wip-us.apache.org/repos/asf/clerezza/commit/2fce006b
Tree: http://git-wip-us.apache.org/repos/asf/clerezza/tree/2fce006b
Diff: http://git-wip-us.apache.org/repos/asf/clerezza/diff/2fce006b

Branch: refs/heads/master
Commit: 2fce006b31d6534ac5daff2f1a5c2c0fcdbd8d7c
Parents: dacd8c7
Author: Reto Gmuer <re...@apache.org>
Authored: Mon May 18 08:55:21 2015 +0000
Committer: Reto Gmuer <re...@apache.org>
Committed: Mon May 18 08:55:21 2015 +0000

----------------------------------------------------------------------
 provisioning/rdf/pom.xml | 5 -----
 1 file changed, 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/clerezza/blob/2fce006b/provisioning/rdf/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/rdf/pom.xml b/provisioning/rdf/pom.xml
index 525a773..59670ec 100644
--- a/provisioning/rdf/pom.xml
+++ b/provisioning/rdf/pom.xml
@@ -102,11 +102,6 @@
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
-            <artifactId>rdf.core</artifactId>
-            <version>1.0.0-SNAPSHOT</version>
-        </dependency>
-        <dependency>
-            <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.ontologies</artifactId>
             <version>1.0.0-SNAPSHOT</version>
         </dependency>


[2/2] clerezza git commit: CLEREZZA-327: added launcher for website

Posted by re...@apache.org.
CLEREZZA-327: added launcher for website

Project: http://git-wip-us.apache.org/repos/asf/clerezza/repo
Commit: http://git-wip-us.apache.org/repos/asf/clerezza/commit/fe6530be
Tree: http://git-wip-us.apache.org/repos/asf/clerezza/tree/fe6530be
Diff: http://git-wip-us.apache.org/repos/asf/clerezza/diff/fe6530be

Branch: refs/heads/master
Commit: fe6530be73a56eeeb3aa535b5790358a3851d4c9
Parents: 2fce006
Author: Reto Gmuer <re...@apache.org>
Authored: Mon May 18 11:40:58 2015 +0000
Committer: Reto Gmuer <re...@apache.org>
Committed: Mon May 18 11:40:58 2015 +0000

----------------------------------------------------------------------
 alerts.txt                                      |   0
 .../platform/content/JaxRsExceptionMapper.java  |  69 +++++
 platform/documentation.viewer/pom.xml           |  16 +-
 .../viewer/DocumentationViewer.java             |  99 ++++---
 .../platform/documentation/viewer/SortTest.java |  50 ++--
 platform/documentation/pom.xml                  |  18 +-
 .../documentation/DocumentationProvider.java    |  93 +++---
 .../documentation/UriMutatorIterator.java       |  44 +--
 .../documentation/UriMutatorIteratorTest.java   |  42 +--
 provisioning/jaxrs-whiteboard/pom.xml           |  20 +-
 provisioning/launchers/pom.xml                  |   1 +
 .../website-launcher/nb-configuration.xml       |  18 ++
 .../launchers/website-launcher/nbactions.xml    |  50 ++++
 provisioning/launchers/website-launcher/pom.xml | 289 +++++++++++++++++++
 .../website-launcher/src/main/bundles/list.xml  |   5 +
 .../website-launcher/src/main/config/note.txt   |   1 +
 provisioning/pom.xml                            |   1 +
 provisioning/site.tools/pom.xml                 |  96 ++++++
 .../site.tools/src/main/feature/feature.xml     |  26 ++
 report.xml                                      |  35 +++
 site/readme.txt                                 |   8 +-
 21 files changed, 796 insertions(+), 185 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/alerts.txt
----------------------------------------------------------------------
diff --git a/alerts.txt b/alerts.txt
new file mode 100644
index 0000000..e69de29

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/content/src/main/java/org/apache/clerezza/platform/content/JaxRsExceptionMapper.java
----------------------------------------------------------------------
diff --git a/platform/content/src/main/java/org/apache/clerezza/platform/content/JaxRsExceptionMapper.java b/platform/content/src/main/java/org/apache/clerezza/platform/content/JaxRsExceptionMapper.java
new file mode 100644
index 0000000..9cff9c9
--- /dev/null
+++ b/platform/content/src/main/java/org/apache/clerezza/platform/content/JaxRsExceptionMapper.java
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2015 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.clerezza.platform.content;
+
+import java.io.PrintWriter;
+import java.io.StringWriter;
+import javax.ws.rs.WebApplicationException;
+import javax.ws.rs.core.Response;
+import javax.ws.rs.ext.ExceptionMapper;
+import javax.ws.rs.ext.Provider;
+import org.apache.felix.scr.annotations.Component;
+import org.apache.felix.scr.annotations.Property;
+import org.apache.felix.scr.annotations.Service;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+/**
+ * Logs exceptions. This is only here lacking a better place.
+ *
+ * @author developer
+ */
+@Component()
+@Service(Object.class)
+@Property(name = "javax.ws.rs", boolValue = true)
+@Provider
+public class JaxRsExceptionMapper implements ExceptionMapper<Throwable> {
+
+    private static final Logger log = LoggerFactory.getLogger(JaxRsExceptionMapper.class);
+
+    @Override
+    public Response toResponse(Throwable exception) {
+        log.error("toResponse() caught exception", exception);
+        if (exception instanceof WebApplicationException) {
+            return ((WebApplicationException) exception).getResponse();
+        }
+        return Response.status(getStatusCode(exception))
+                .entity(getEntity(exception))
+                .build();
+    }
+
+    /*
+     * Get appropriate HTTP status code for an exception.
+     */
+    private int getStatusCode(Throwable exception) {
+        return Response.Status.INTERNAL_SERVER_ERROR.getStatusCode();
+    }
+
+    /*
+     * Get response body for an exception.
+     */
+    private Object getEntity(Throwable exception) {
+        StringWriter errorMsg = new StringWriter();
+        exception.printStackTrace(new PrintWriter(errorMsg));
+        return errorMsg.toString();            
+    }
+}

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation.viewer/pom.xml
----------------------------------------------------------------------
diff --git a/platform/documentation.viewer/pom.xml b/platform/documentation.viewer/pom.xml
index 1d9be7c..0c70fe1 100644
--- a/platform/documentation.viewer/pom.xml
+++ b/platform/documentation.viewer/pom.xml
@@ -25,8 +25,8 @@
     <parent>
         <groupId>org.apache.clerezza</groupId>
         <artifactId>clerezza</artifactId>
-        <version>0.5</version>
-        <relativePath>../parent</relativePath>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
     </parent>
     <groupId>org.apache.clerezza</groupId>
     <artifactId>platform.documentation.viewer</artifactId>
@@ -36,6 +36,14 @@
     <name>Clerezza - Platform Documentation Viewer</name>
     <description>Presents the documentation of the Clerezza Platform
     </description>
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.felix</groupId>
+                <artifactId>maven-scr-plugin</artifactId>
+            </plugin>  
+        </plugins>
+    </build>
     <dependencies>
         <dependency>
             <groupId>javax.ws.rs</groupId>
@@ -44,12 +52,12 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.utils</artifactId>
-            <version>0.14</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.documentation</artifactId>
-            <version>0.4</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation.viewer/src/main/java/org/apache/clerezza/platform/documentation/viewer/DocumentationViewer.java
----------------------------------------------------------------------
diff --git a/platform/documentation.viewer/src/main/java/org/apache/clerezza/platform/documentation/viewer/DocumentationViewer.java b/platform/documentation.viewer/src/main/java/org/apache/clerezza/platform/documentation/viewer/DocumentationViewer.java
index 32ad8d7..7dfe617 100644
--- a/platform/documentation.viewer/src/main/java/org/apache/clerezza/platform/documentation/viewer/DocumentationViewer.java
+++ b/platform/documentation.viewer/src/main/java/org/apache/clerezza/platform/documentation/viewer/DocumentationViewer.java
@@ -35,39 +35,41 @@ import javax.ws.rs.core.Response;
 import javax.ws.rs.core.UriInfo;
 import org.apache.clerezza.jaxrs.utils.TrailingSlash;
 import org.apache.clerezza.platform.documentation.DocumentationProvider;
-import org.apache.clerezza.rdf.core.BNode;
-import org.apache.clerezza.rdf.core.Graph;
-import org.apache.clerezza.rdf.core.LiteralFactory;
-import org.apache.clerezza.rdf.core.MGraph;
-import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.UriRef;
+import org.apache.clerezza.commons.rdf.BlankNode;
+import org.apache.clerezza.commons.rdf.ImmutableGraph;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.Triple;
+import org.apache.clerezza.commons.rdf.IRI;
 import org.apache.clerezza.rdf.core.access.TcManager;
-import org.apache.clerezza.rdf.core.impl.PlainLiteralImpl;
-import org.apache.clerezza.rdf.core.impl.SimpleMGraph;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.PlainLiteralImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleGraph;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
+import org.apache.clerezza.rdf.core.LiteralFactory;
 import org.apache.clerezza.rdf.ontologies.DISCOBITS;
 import org.apache.clerezza.rdf.ontologies.RDF;
 import org.apache.clerezza.rdf.ontologies.DOCUMENTATION;
 import org.apache.clerezza.rdf.utils.GraphNode;
-import org.apache.clerezza.rdf.utils.UnionMGraph;
+import org.apache.clerezza.rdf.utils.UnionGraph;
+import org.apache.felix.scr.annotations.Component;
+import org.apache.felix.scr.annotations.Property;
+import org.apache.felix.scr.annotations.Reference;
+import org.apache.felix.scr.annotations.Service;
 
 /**
  *
  * The documentation viewer provides a webpage that shows the available
  * documentation.
  *
- * @scr.component
- * @scr.service interface="java.lang.Object"
- * @scr.property name="javax.ws.rs" type="Boolean" value="true"
  *
  * @author mir
  */
+@Component()
+@Service(Object.class)
+@Property(name="javax.ws.rs", boolValue=true)
 @Path("/documentation")
 public class DocumentationViewer {
 
-    /**
-     * @scr.reference
-     */
+    @Reference
     private TcManager tcManager;
         
     /**
@@ -79,33 +81,33 @@ public class DocumentationViewer {
     @GET
     public GraphNode documentationPage(@Context UriInfo uriInfo) {
         TrailingSlash.enforcePresent(uriInfo);
-        Graph documentations = tcManager.getGraph(
+        ImmutableGraph documentations = tcManager.getImmutableGraph(
                 DocumentationProvider.DOCUMENTATION_GRAPH_URI);        
         Collection<DocumentationItem> docItems = getDocItems(documentations);        
         List<DocumentationItem> sortedDocItems = sortDocItems(docItems);        
-        MGraph mGraph = new SimpleMGraph();
-        BNode orderedContent = createOrderedContent(sortedDocItems, mGraph);
-        BNode titledContent = createTitledContent(orderedContent, mGraph);
-        MGraph resultGraph = new UnionMGraph(mGraph, documentations);
+        Graph mGraph = new SimpleGraph();
+        BlankNode orderedContent = createOrderedContent(sortedDocItems, mGraph);
+        BlankNode titledContent = createTitledContent(orderedContent, mGraph);
+        Graph resultGraph = new UnionGraph(mGraph, documentations);
         GraphNode resultNode = new GraphNode(titledContent, resultGraph);
         return resultNode;
     }
 
-    private Collection<DocumentationItem> getDocItems(Graph documentations) {
+    private Collection<DocumentationItem> getDocItems(ImmutableGraph documentations) {
         Iterator<Triple> docs = documentations.filter(null, 
                 DOCUMENTATION.documentation, null);        
 
-        Map<UriRef,DocumentationItem> uri2docItemObj = 
-            new HashMap<UriRef,DocumentationItem>();
+        Map<IRI,DocumentationItem> uri2docItemObj = 
+            new HashMap<IRI,DocumentationItem>();
         
         while (docs.hasNext()) {
             Triple docc = docs.next();
-            UriRef docItem = (UriRef) docc.getObject();
+            IRI docItem = (IRI) docc.getObject();
             Iterator<Triple> afterDocItemsIter = documentations.filter(docItem,
                 DOCUMENTATION.after, null);
-            Set<UriRef> afterDocItems = new HashSet<UriRef>();
+            Set<IRI> afterDocItems = new HashSet<IRI>();
             while (afterDocItemsIter.hasNext()) {
-                afterDocItems.add((UriRef) afterDocItemsIter.next().getObject());
+                afterDocItems.add((IRI) afterDocItemsIter.next().getObject());
             }
             DocumentationItem docItemObj = new DocumentationItem(
                     docItem, afterDocItems, uri2docItemObj);
@@ -133,15 +135,15 @@ public class DocumentationViewer {
         return result;
     }
 
-    private BNode createOrderedContent(List<DocumentationItem> sortedDocItems,
-        MGraph mGraph) {
-        BNode orderedContent = new BNode();
+    private BlankNode createOrderedContent(List<DocumentationItem> sortedDocItems,
+        Graph mGraph) {
+        BlankNode orderedContent = new BlankNode();
         mGraph.add(new TripleImpl(orderedContent, RDF.type, DISCOBITS.OrderedContent));
         Integer pos = 0;
         Iterator<DocumentationItem> docItemObjsIter = sortedDocItems.iterator();
         while (docItemObjsIter.hasNext()) {
             DocumentationItem docItemObj = docItemObjsIter.next();
-            BNode containedDoc = new BNode();
+            BlankNode containedDoc = new BlankNode();
             mGraph.add(new TripleImpl(orderedContent, DISCOBITS.contains,
                     containedDoc));
             mGraph.add(new TripleImpl(containedDoc, DISCOBITS.pos,
@@ -153,19 +155,19 @@ public class DocumentationViewer {
         return orderedContent;
     }
 
-    private BNode createTitledContent(BNode orderedContent, MGraph mGraph) {
-        BNode titledContent = new BNode();
+    private BlankNode createTitledContent(BlankNode orderedContent, Graph mGraph) {
+        BlankNode titledContent = new BlankNode();
         mGraph.add(new TripleImpl(titledContent, RDF.type, DISCOBITS.TitledContent));
-        BNode title = new BNode();
+        BlankNode title = new BlankNode();
         mGraph.add(new TripleImpl(title, DISCOBITS.pos, new PlainLiteralImpl("0")));
-        BNode titleXml = new BNode();
+        BlankNode titleXml = new BlankNode();
         mGraph.add(new TripleImpl(titleXml, RDF.type, DISCOBITS.XHTMLInfoDiscoBit));
         mGraph.add(new TripleImpl(titleXml, DISCOBITS.infoBit,
                 LiteralFactory.getInstance().createTypedLiteral("Documentation")));
         mGraph.add(new TripleImpl(title, DISCOBITS.holds, titleXml));
         mGraph.add(new TripleImpl(title, RDF.type, DISCOBITS.Entry));
         mGraph.add(new TripleImpl(titledContent, DISCOBITS.contains, title));        
-        BNode content = new BNode();
+        BlankNode content = new BlankNode();
         mGraph.add(new TripleImpl(content, DISCOBITS.pos, new PlainLiteralImpl("1")));
         mGraph.add(new TripleImpl(content, DISCOBITS.holds, orderedContent));
         mGraph.add(new TripleImpl(content, RDF.type, DISCOBITS.Entry));
@@ -175,34 +177,35 @@ public class DocumentationViewer {
 
     protected static class DocumentationItem {
 
-        private UriRef documentationItem;
-        private Set<UriRef> afterDocItems;
+        private IRI documentationItem;
+        private Set<IRI> afterDocItems;
         
         private boolean transitiveAfterDocItemsAdded = false;
-        private Map<UriRef, DocumentationItem> uri2docItemObj;
+        private Map<IRI, DocumentationItem> uri2docItemObj;
 
-        DocumentationItem(UriRef doumentationItem, Set<UriRef> explicitAfterDocItems,
-            Map<UriRef, DocumentationItem> uri2docItemObj) {
+        DocumentationItem(IRI doumentationItem, Set<IRI> explicitAfterDocItems,
+            Map<IRI, DocumentationItem> uri2docItemObj) {
             this.documentationItem = doumentationItem;
             this.afterDocItems = explicitAfterDocItems;
             this.uri2docItemObj = uri2docItemObj;
         }
 
-        public boolean isAfer(UriRef docItem) {
+        public boolean isAfer(IRI docItem) {
             return getAfterDocItems().contains(docItem);
         }
         
-        private Set<UriRef> getAfterDocItems() {
+        private Set<IRI> getAfterDocItems() {
             Stack<DocumentationItem> stack = new Stack<DocumentationItem>();
             stack.add(this);
             return getAfterDocItems(stack);
         }
         
-        private Set<UriRef> getAfterDocItems(Stack<DocumentationItem> stack) {
+        private Set<IRI> getAfterDocItems(Stack<DocumentationItem> stack) {
             if (!transitiveAfterDocItemsAdded) {
-                Iterator<UriRef> afterDocUrisIter = afterDocItems.iterator();
+                Set<IRI> afterDocItemsClone = new HashSet<>(afterDocItems);
+                Iterator<IRI> afterDocUrisIter = afterDocItemsClone.iterator();
                 while (afterDocUrisIter.hasNext()) {
-                    UriRef uriRef = afterDocUrisIter.next();
+                    IRI uriRef = afterDocUrisIter.next();
                     DocumentationItem docItem = uri2docItemObj.get(uriRef);
                     if (stack.contains(docItem)) {
                         throw new RuntimeException("Documentation: cycle detected!\n"
@@ -223,9 +226,9 @@ public class DocumentationViewer {
             writer.append("[");
             writer.append(documentationItem.getUnicodeString());
             writer.append(" is after (");
-            Iterator<UriRef> afterDocs = afterDocItems.iterator();
+            Iterator<IRI> afterDocs = afterDocItems.iterator();
             while (afterDocs.hasNext()) {
-                UriRef uriRef = afterDocs.next();
+                IRI uriRef = afterDocs.next();
                 writer.append(uriRef.getUnicodeString());
                 if (afterDocs.hasNext()) {
                     writer.append(",");

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation.viewer/src/test/java/org/apache/clerezza/platform/documentation/viewer/SortTest.java
----------------------------------------------------------------------
diff --git a/platform/documentation.viewer/src/test/java/org/apache/clerezza/platform/documentation/viewer/SortTest.java b/platform/documentation.viewer/src/test/java/org/apache/clerezza/platform/documentation/viewer/SortTest.java
index a980223..65dbbed 100644
--- a/platform/documentation.viewer/src/test/java/org/apache/clerezza/platform/documentation/viewer/SortTest.java
+++ b/platform/documentation.viewer/src/test/java/org/apache/clerezza/platform/documentation/viewer/SortTest.java
@@ -26,7 +26,7 @@ import java.util.Map;
 import java.util.Set;
 import org.junit.Assert;
 import org.junit.Test;
-import org.apache.clerezza.rdf.core.UriRef;
+import org.apache.clerezza.commons.rdf.IRI;
 
 /**
  *
@@ -38,34 +38,34 @@ public class SortTest {
     public void sortTest() {
         DocumentationViewer docViewer = new DocumentationViewer();
 
-        Map<UriRef,DocumentationViewer.DocumentationItem> uri2docItemObj =
-            new HashMap<UriRef,DocumentationViewer.DocumentationItem>();
-        UriRef ref1 = new UriRef("ref1");
-        UriRef ref2 = new UriRef("ref2");
-        UriRef ref3 = new UriRef("ref3");
-        UriRef ref4 = new UriRef("ref4");
-        UriRef ref5 = new UriRef("ref5");
+        Map<IRI,DocumentationViewer.DocumentationItem> uri2docItemObj =
+            new HashMap<IRI,DocumentationViewer.DocumentationItem>();
+        IRI ref1 = new IRI("ref1");
+        IRI ref2 = new IRI("ref2");
+        IRI ref3 = new IRI("ref3");
+        IRI ref4 = new IRI("ref4");
+        IRI ref5 = new IRI("ref5");
 
-        Set<UriRef> set1 = new HashSet<UriRef>();
+        Set<IRI> set1 = new HashSet<IRI>();
         DocumentationViewer.DocumentationItem a =
             new DocumentationViewer.DocumentationItem(ref1, set1, uri2docItemObj);
 
-        Set<UriRef> set2 = new HashSet<UriRef>();
+        Set<IRI> set2 = new HashSet<IRI>();
         set2.add(ref1);
         DocumentationViewer.DocumentationItem b =
             new DocumentationViewer.DocumentationItem(ref2, set2, uri2docItemObj);
 
-        Set<UriRef> set3 = new HashSet<UriRef>();
+        Set<IRI> set3 = new HashSet<IRI>();
         set3.add(ref2);
         DocumentationViewer.DocumentationItem c =
             new DocumentationViewer.DocumentationItem(ref3, set3, uri2docItemObj);
 
-        Set<UriRef> set4 = new HashSet<UriRef>();
+        Set<IRI> set4 = new HashSet<IRI>();
         set4.add(ref3);
         DocumentationViewer.DocumentationItem d =
             new DocumentationViewer.DocumentationItem(ref4, set4, uri2docItemObj);
 
-        Set<UriRef> set5 = new HashSet<UriRef>();
+        Set<IRI> set5 = new HashSet<IRI>();
         set5.add(ref4);
         DocumentationViewer.DocumentationItem e =
             new DocumentationViewer.DocumentationItem(ref5, set5, uri2docItemObj);
@@ -98,35 +98,35 @@ public class SortTest {
     public void cycleTest() {
         DocumentationViewer docViewer = new DocumentationViewer();
 
-        Map<UriRef,DocumentationViewer.DocumentationItem> uri2docItemObj =
-            new HashMap<UriRef,DocumentationViewer.DocumentationItem>();
-        UriRef ref1 = new UriRef("ref1");
-        UriRef ref2 = new UriRef("ref2");
-        UriRef ref3 = new UriRef("ref3");
-        UriRef ref4 = new UriRef("ref4");
-        UriRef ref5 = new UriRef("ref5");
+        Map<IRI,DocumentationViewer.DocumentationItem> uri2docItemObj =
+            new HashMap<IRI,DocumentationViewer.DocumentationItem>();
+        IRI ref1 = new IRI("ref1");
+        IRI ref2 = new IRI("ref2");
+        IRI ref3 = new IRI("ref3");
+        IRI ref4 = new IRI("ref4");
+        IRI ref5 = new IRI("ref5");
 
-        Set<UriRef> set1 = new HashSet<UriRef>();
+        Set<IRI> set1 = new HashSet<IRI>();
         set1.add(ref5);
         DocumentationViewer.DocumentationItem a =
             new DocumentationViewer.DocumentationItem(ref1, set1, uri2docItemObj);
 
-        Set<UriRef> set2 = new HashSet<UriRef>();
+        Set<IRI> set2 = new HashSet<IRI>();
         set2.add(ref1);
         DocumentationViewer.DocumentationItem b =
             new DocumentationViewer.DocumentationItem(ref2, set2, uri2docItemObj);
 
-        Set<UriRef> set3 = new HashSet<UriRef>();
+        Set<IRI> set3 = new HashSet<IRI>();
         set3.add(ref2);
         DocumentationViewer.DocumentationItem c =
             new DocumentationViewer.DocumentationItem(ref3, set3, uri2docItemObj);
 
-        Set<UriRef> set4 = new HashSet<UriRef>();
+        Set<IRI> set4 = new HashSet<IRI>();
         set4.add(ref3);
         DocumentationViewer.DocumentationItem d =
             new DocumentationViewer.DocumentationItem(ref4, set4, uri2docItemObj);
 
-        Set<UriRef> set5 = new HashSet<UriRef>();
+        Set<IRI> set5 = new HashSet<IRI>();
         set5.add(ref4);
         DocumentationViewer.DocumentationItem e =
             new DocumentationViewer.DocumentationItem(ref5, set5, uri2docItemObj);

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation/pom.xml
----------------------------------------------------------------------
diff --git a/platform/documentation/pom.xml b/platform/documentation/pom.xml
index cd4b989..4176f21 100644
--- a/platform/documentation/pom.xml
+++ b/platform/documentation/pom.xml
@@ -24,8 +24,8 @@
     <parent>
         <artifactId>clerezza</artifactId>
         <groupId>org.apache.clerezza</groupId>
-        <version>0.5</version>
-        <relativePath>../parent</relativePath>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
     </parent>
     <groupId>org.apache.clerezza</groupId>
     <artifactId>platform.documentation</artifactId>
@@ -34,6 +34,14 @@
     <name>Clerezza - Platform Documentation</name>
     <description>Manages the documentation of the Clerezza Platform
     </description>
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.felix</groupId>
+                <artifactId>maven-scr-plugin</artifactId>
+            </plugin>  
+        </plugins>
+    </build>
     <dependencies>
         <dependency>
             <groupId>junit</groupId>
@@ -55,17 +63,17 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.utils</artifactId>
-            <version>0.14</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.graphprovider.content</artifactId>
-            <version>0.7</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.config</artifactId>
-            <version>0.4</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.felix</groupId>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/DocumentationProvider.java
----------------------------------------------------------------------
diff --git a/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/DocumentationProvider.java b/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/DocumentationProvider.java
index 3923a8b..9731e99 100644
--- a/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/DocumentationProvider.java
+++ b/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/DocumentationProvider.java
@@ -38,26 +38,27 @@ import org.osgi.service.component.ComponentContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.clerezza.platform.config.PlatformConfig;
-import org.apache.clerezza.rdf.core.Graph;
-import org.apache.clerezza.rdf.core.MGraph;
-import org.apache.clerezza.rdf.core.NonLiteral;
-import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.TripleCollection;
-import org.apache.clerezza.rdf.core.UriRef;
+import org.apache.clerezza.commons.rdf.ImmutableGraph;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.BlankNodeOrIRI;
+import org.apache.clerezza.commons.rdf.Triple;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.IRI;
 import org.apache.clerezza.rdf.core.access.EntityAlreadyExistsException;
 import org.apache.clerezza.rdf.core.access.EntityUndeletableException;
 import org.apache.clerezza.rdf.core.access.NoSuchEntityException;
 import org.apache.clerezza.rdf.core.access.WeightedTcProvider;
-import org.apache.clerezza.rdf.core.impl.SimpleGraph;
-import org.apache.clerezza.rdf.core.impl.SimpleMGraph;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleGraph;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleGraph;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleImmutableGraph;
 import org.apache.clerezza.rdf.core.serializedform.Parser;
 import org.apache.clerezza.rdf.core.serializedform.SupportedFormat;
 import org.apache.clerezza.rdf.ontologies.DISCOBITS;
 import org.apache.clerezza.rdf.ontologies.DOCUMENTATION;
 import org.apache.clerezza.rdf.ontologies.OSGI;
 import org.apache.clerezza.rdf.ontologies.RDF;
-import org.apache.clerezza.rdf.utils.UnionMGraph;
+import org.apache.clerezza.rdf.utils.UnionGraph;
 
 /**
  * The DocumentationProvider gathers the documentations of bundles and provides
@@ -90,19 +91,19 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
     /**
      * Contains the map between bundles and their documentation-graph
      */
-    private Map<Bundle, MGraph> bundle2DocGraphMap = new HashMap<Bundle, MGraph>();
+    private Map<Bundle, Graph> bundle2DocGraphMap = new HashMap<Bundle, Graph>();
 
     /**
      * UnionGraph which contains all documenation-graphs of the registered
      * bundles
      */
-    private Graph unitedDocumentations;
+    private ImmutableGraph unitedDocumentations;
 
     /**
      * The URI of the graph containing the documentations
      */
-    public static final UriRef DOCUMENTATION_GRAPH_URI =
-            new UriRef("urn:x-localinstance:/documentation.graph");
+    public static final IRI DOCUMENTATION_GRAPH_URI =
+            new IRI("urn:x-localinstance:/documentation.graph");
 
     private int weight = 30;    
 
@@ -112,7 +113,7 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
     }
 
     @Override
-    public Graph getGraph(UriRef name) throws NoSuchEntityException {
+    public ImmutableGraph getImmutableGraph(IRI name) throws NoSuchEntityException {
         if (name.equals(DOCUMENTATION_GRAPH_URI)) {
             return unitedDocumentations;
         }
@@ -120,52 +121,52 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
     }
 
     @Override
-    public MGraph getMGraph(UriRef name) throws NoSuchEntityException {
+    public Graph getMGraph(IRI name) throws NoSuchEntityException {
         throw new NoSuchEntityException(name);
     }
 
     @Override
-    public TripleCollection getTriples(UriRef name) throws NoSuchEntityException {
-        return getGraph(name);
+    public Graph getGraph(IRI name) throws NoSuchEntityException {
+        return getImmutableGraph(name);
     }
 
     @Override
-    public Set<UriRef> listGraphs() {
+    public Set<IRI> listImmutableGraphs() {
         return Collections.singleton(DOCUMENTATION_GRAPH_URI);
     }
 
     @Override
-    public Set<UriRef> listMGraphs() {
-        return new HashSet<UriRef>();
+    public Set<IRI> listMGraphs() {
+        return new HashSet<IRI>();
     }
 
     @Override
-    public Set<UriRef> listTripleCollections() {
+    public Set<IRI> listGraphs() {
         return Collections.singleton(DOCUMENTATION_GRAPH_URI);
     }
 
     @Override
-    public MGraph createMGraph(UriRef name)
+    public Graph createGraph(IRI name)
             throws UnsupportedOperationException, EntityAlreadyExistsException {
         throw new UnsupportedOperationException("Not supported.");
     }
 
     @Override
-    public Graph createGraph(UriRef name, TripleCollection triples)
+    public ImmutableGraph createImmutableGraph(IRI name, Graph triples)
             throws UnsupportedOperationException, EntityAlreadyExistsException {
         throw new UnsupportedOperationException("Not supported.");
     }
 
     @Override
-    public void deleteTripleCollection(UriRef name)
+    public void deleteGraph(IRI name)
             throws UnsupportedOperationException, NoSuchEntityException,
             EntityUndeletableException {
         throw new UnsupportedOperationException("Not supported.");
     }
 
     @Override
-    public Set<UriRef> getNames(Graph graph) {
-        final HashSet<UriRef> result = new HashSet<UriRef>();
+    public Set<IRI> getNames(ImmutableGraph graph) {
+        final HashSet<IRI> result = new HashSet<IRI>();
         if (unitedDocumentations.equals(graph)) {
             result.add(DOCUMENTATION_GRAPH_URI);
         }
@@ -211,19 +212,19 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
         if (entry == null) {
             return;
         }
-        MGraph docMGraph = getDocumentationMGraph(entry, bundle.getSymbolicName());
-        addAdditionalTriples(bundle, docMGraph);
-        bundle2DocGraphMap.put(bundle, docMGraph);
+        Graph docGraph = getDocumentationGraph(entry, bundle.getSymbolicName());
+        addAdditionalTriples(bundle, docGraph);
+        bundle2DocGraphMap.put(bundle, docGraph);
         logger.info("Registered documentation of bundle: {}",
                 bundle.getSymbolicName());
     }
 
-    private MGraph getDocumentationMGraph(URL docUrl, String symbolicName) {
+    private Graph getDocumentationGraph(URL docUrl, String symbolicName) {
         try {
-            Graph parsedGraph = parser.parse(docUrl.openStream(),
+            ImmutableGraph parsedGraph = parser.parse(docUrl.openStream(),
                     SupportedFormat.N_TRIPLE);
-            UriRef baseUri = config.getDefaultBaseUri();
-            return new SimpleMGraph(new UriMutatorIterator(
+            IRI baseUri = config.getDefaultBaseUri();
+            return new SimpleGraph(new UriMutatorIterator(
                     parsedGraph.iterator(), baseUri.getUnicodeString(), symbolicName));
         } catch (IOException ex) {
             logger.warn("Cannot parse documentation at URL: {}", docUrl);
@@ -235,25 +236,25 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
      * Adds triples that point from the bundle resource to its documentations.
      *
      * @param bundle
-     * @param docMGraph
+     * @param docGraph
      */
-    private void addAdditionalTriples(Bundle bundle, MGraph docMGraph) {
-        UriRef bundleUri = new UriRef(bundle.getLocation());
+    private void addAdditionalTriples(Bundle bundle, Graph docGraph) {
+        IRI bundleUri = new IRI(bundle.getLocation());
         Triple triple = new TripleImpl(bundleUri, RDF.type, OSGI.Bundle);
-        docMGraph.add(triple);
-        Iterator<Triple> titledContents = docMGraph.filter(null, RDF.type,
+        docGraph.add(triple);
+        Iterator<Triple> titledContents = docGraph.filter(null, RDF.type,
                 DISCOBITS.TitledContent);
         Set<Triple> newTriples = new HashSet<Triple>();
         for (Iterator<Triple> it = titledContents; it.hasNext();) {
-            NonLiteral titledContent = it.next().getSubject();
-            if (docMGraph.filter(null, DISCOBITS.holds, titledContent).hasNext()) {
+            BlankNodeOrIRI titledContent = it.next().getSubject();
+            if (docGraph.filter(null, DISCOBITS.holds, titledContent).hasNext()) {
                 continue;
             }
             triple = new TripleImpl(bundleUri, DOCUMENTATION.documentation,
                     titledContent);
             newTriples.add(triple);
         }
-        docMGraph.addAll(newTriples);
+        docGraph.addAll(newTriples);
     }
 
     private void unregisterDocumentation(Bundle bundle) {
@@ -263,12 +264,12 @@ public class DocumentationProvider implements WeightedTcProvider, BundleListener
     }
 
     private void createUnionGraph() {
-        MGraph[] docGraphs = bundle2DocGraphMap.values().
-                toArray(new MGraph[bundle2DocGraphMap.size()]);
+        Graph[] docGraphs = bundle2DocGraphMap.values().
+                toArray(new Graph[bundle2DocGraphMap.size()]);
         if (docGraphs.length > 0) {
-            unitedDocumentations = new SimpleGraph(new UnionMGraph(docGraphs), true);
+            unitedDocumentations = new SimpleImmutableGraph(new UnionGraph(docGraphs), true);
         } else {
-            unitedDocumentations = new SimpleGraph(new SimpleMGraph(), true);
+            unitedDocumentations = new SimpleImmutableGraph(new SimpleGraph(), true);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/UriMutatorIterator.java
----------------------------------------------------------------------
diff --git a/platform/documentation/src/test/java/org/apache/clerezza/platform/documentation/UriMutatorIteratorTest.java b/platform/documentation/src/test/java/org/apache/clerezza/platform/documentation/UriMutatorIteratorTest.java
index 652dd1c..7f4b3c6 100644
--- a/platform/documentation/src/test/java/org/apache/clerezza/platform/documentation/UriMutatorIteratorTest.java
+++ b/platform/documentation/src/test/java/org/apache/clerezza/platform/documentation/UriMutatorIteratorTest.java
@@ -21,13 +21,13 @@ package org.apache.clerezza.platform.documentation;
 import java.util.Iterator;
 import org.junit.Assert;
 import org.junit.Test;
-import org.apache.clerezza.rdf.core.Literal;
-import org.apache.clerezza.rdf.core.MGraph;
-import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.UriRef;
-import org.apache.clerezza.rdf.core.impl.SimpleMGraph;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
-import org.apache.clerezza.rdf.core.impl.TypedLiteralImpl;
+import org.apache.clerezza.commons.rdf.Literal;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.Triple;
+import org.apache.clerezza.commons.rdf.IRI;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleGraph;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.TypedLiteralImpl;
 
 /**
  *
@@ -43,37 +43,37 @@ public class UriMutatorIteratorTest {
 
     @Test
     public void testMutator() {
-        MGraph mGraph = new SimpleMGraph();
-        UriRef uriRef = new UriRef(UriMutatorIterator.BASE_URI_PLACEHOLDER +
+        Graph mGraph = new SimpleGraph();
+        IRI uriRef = new IRI(UriMutatorIterator.BASE_URI_PLACEHOLDER +
                 REFERENCED_BUNDLE_NAME + "/bla#Test");
-        UriRef expectedUriRef = new UriRef(HOST + 
+        IRI expectedIRI = new IRI(HOST + 
                 "bundle-doc/"+ REFERENCED_BUNDLE_NAME +"/bla#Test");
         mGraph.add(new TripleImpl(uriRef, uriRef, uriRef));
         Iterator<Triple> it = new UriMutatorIterator(mGraph.iterator(), HOST,
                 ORIGIN_BUNDLE_NAME);
-        Triple expectedTriple = new TripleImpl(expectedUriRef, expectedUriRef,
-                expectedUriRef);
+        Triple expectedTriple = new TripleImpl(expectedIRI, expectedIRI,
+                expectedIRI);
         Assert.assertEquals(expectedTriple, it.next());        
     }
 
     @Test
     public void testMutatorNoSymbolicName() {
-        MGraph mGraph = new SimpleMGraph();
-        UriRef uriRef = new UriRef(UriMutatorIterator.BASE_URI_PLACEHOLDER +
+        Graph mGraph = new SimpleGraph();
+        IRI uriRef = new IRI(UriMutatorIterator.BASE_URI_PLACEHOLDER +
                 "/bla#Test");
-        UriRef expectedUriRef = new UriRef(HOST +
+        IRI expectedIRI = new IRI(HOST +
                 "bundle-doc/"+ ORIGIN_BUNDLE_NAME +"/bla#Test");
         mGraph.add(new TripleImpl(uriRef, uriRef, uriRef));
         Iterator<Triple> it = new UriMutatorIterator(mGraph.iterator(), HOST,
                 ORIGIN_BUNDLE_NAME);
-        Triple expectedTriple = new TripleImpl(expectedUriRef, expectedUriRef,
-                expectedUriRef);
+        Triple expectedTriple = new TripleImpl(expectedIRI, expectedIRI,
+                expectedIRI);
         Assert.assertEquals(expectedTriple, it.next());
     }
 
     @Test
     public void baseUriTransformation() {
-        MGraph mGraph = new SimpleMGraph();
+        Graph mGraph = new SimpleGraph();
         String xml = "<a href=\"" + UriMutatorIterator.BASE_URI_PLACEHOLDER +
             REFERENCED_BUNDLE_NAME + "/bla\"/>";
         Literal literal = new TypedLiteralImpl(xml,
@@ -82,7 +82,7 @@ public class UriMutatorIteratorTest {
             "bundle-doc/"+ REFERENCED_BUNDLE_NAME +"/bla\"/>";
         Literal expectedLiteral = new TypedLiteralImpl(expectedXml,
                     UriMutatorIterator.XML_LITERAL);
-        UriRef uriRef = new UriRef("bla");
+        IRI uriRef = new IRI("bla");
             mGraph.add(new TripleImpl(uriRef, uriRef, literal));
         Iterator<Triple> it = new UriMutatorIterator(mGraph.iterator(), HOST,
                 ORIGIN_BUNDLE_NAME);
@@ -93,7 +93,7 @@ public class UriMutatorIteratorTest {
 
     @Test
     public void baseUriTransformationNoSymbolicName() {
-        MGraph mGraph = new SimpleMGraph();
+        Graph mGraph = new SimpleGraph();
         String xml = "<a href=\"" + UriMutatorIterator.BASE_URI_PLACEHOLDER +
             "/bla\"/>";
         Literal literal = new TypedLiteralImpl(xml,
@@ -102,7 +102,7 @@ public class UriMutatorIteratorTest {
             "bundle-doc/"+ ORIGIN_BUNDLE_NAME +"/bla\"/>";
         Literal expectedLiteral = new TypedLiteralImpl(expectedXml,
                     UriMutatorIterator.XML_LITERAL);
-        UriRef uriRef = new UriRef("bla");
+        IRI uriRef = new IRI("bla");
             mGraph.add(new TripleImpl(uriRef, uriRef, literal));
         Iterator<Triple> it = new UriMutatorIterator(mGraph.iterator(), HOST,
                 ORIGIN_BUNDLE_NAME);

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/jaxrs-whiteboard/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/jaxrs-whiteboard/pom.xml b/provisioning/jaxrs-whiteboard/pom.xml
index e964348..1b68534 100644
--- a/provisioning/jaxrs-whiteboard/pom.xml
+++ b/provisioning/jaxrs-whiteboard/pom.xml
@@ -58,17 +58,17 @@
         <dependency>
             <groupId>org.glassfish.jersey.core</groupId>
             <artifactId>jersey-common</artifactId>
-            <version>2.8</version>
+            <version>2.17</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.jersey.core</groupId>
             <artifactId>jersey-server</artifactId>
-            <version>2.8</version>
+            <version>2.17</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.jersey.core</groupId>
             <artifactId>jersey-client</artifactId>
-            <version>2.8</version>
+            <version>2.17</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.jersey.containers</groupId>
@@ -76,22 +76,22 @@
             use "jersey-container-servlet-core", otherwise
             "jersey-container-servlet"        -->
             <artifactId>jersey-container-servlet-core</artifactId>
-            <version>2.8</version>
+            <version>2.17</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2</groupId>
             <artifactId>hk2-api</artifactId>
-            <version>2.2.0</version>
+            <version>2.3.0</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2</groupId>
             <artifactId>hk2-locator</artifactId>
-            <version>2.2.0</version>
+            <version>2.3.0</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2</groupId>
             <artifactId>hk2-utils</artifactId>
-            <version>2.2.0</version>
+            <version>2.3.0</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2</groupId>
@@ -102,12 +102,12 @@
         <dependency>
             <groupId>org.glassfish.hk2.external</groupId>
             <artifactId>javax.inject</artifactId>
-            <version>2.2.0</version>
+            <version>2.3.0</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2.external</groupId>
             <artifactId>asm-all-repackaged</artifactId>
-            <version>2.2.0</version>
+            <version>2.3.0</version>
         </dependency>
         <dependency>
             <groupId>org.glassfish.hk2.external</groupId>
@@ -127,7 +127,7 @@
         <dependency>
             <groupId>org.glassfish.jersey.bundles.repackaged</groupId>
             <artifactId>jersey-guava</artifactId>
-            <version>2.9.1</version>
+            <version>2.17</version>
         </dependency>
         <dependency>
             <groupId>javax.validation</groupId>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/pom.xml b/provisioning/launchers/pom.xml
index ac885f9..e69c04e 100644
--- a/provisioning/launchers/pom.xml
+++ b/provisioning/launchers/pom.xml
@@ -47,6 +47,7 @@
         <module>linked-data-launcher</module>
         <module>content-launcher</module>
         <module>shell-launcher</module>
+        <module>website-launcher</module>
         <module>full-launcher</module>
     </modules>
 </project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/website-launcher/nb-configuration.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/website-launcher/nb-configuration.xml b/provisioning/launchers/website-launcher/nb-configuration.xml
new file mode 100644
index 0000000..ec4540c
--- /dev/null
+++ b/provisioning/launchers/website-launcher/nb-configuration.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project-shared-configuration>
+    <!--
+This file contains additional configuration written by modules in the NetBeans IDE.
+The configuration is intended to be shared among all the users of project and
+therefore it is assumed to be part of version control checkout.
+Without this configuration present, some functionality in the IDE may be limited or fail altogether.
+-->
+    <properties xmlns="http://www.netbeans.org/ns/maven-properties-data/1">
+        <!--
+Properties that influence various parts of the IDE, especially code formatting and the like. 
+You can copy and paste the single properties, into the pom.xml file and the IDE will pick them up.
+That way multiple projects can share the same settings (useful for formatting rules for example).
+Any value defined here will override the pom.xml file value but is only applicable to the current project.
+-->
+        <netbeans.compile.on.save>none</netbeans.compile.on.save>
+    </properties>
+</project-shared-configuration>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/website-launcher/nbactions.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/website-launcher/nbactions.xml b/provisioning/launchers/website-launcher/nbactions.xml
new file mode 100644
index 0000000..101fb77
--- /dev/null
+++ b/provisioning/launchers/website-launcher/nbactions.xml
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<actions>
+  <action>
+    <actionName>run</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+  </action>
+  <action>
+    <actionName>debug</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+    <properties>
+      <vm.args>-Xdebug -Xrunjdwp:transport=dt_socket,server=n,address=${jpda.address}</vm.args>
+      <jpda.listen>true</jpda.listen>
+    </properties>
+  </action>
+  <action>
+    <actionName>profile</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+    <properties>
+      <vm.args>${profiler.args}</vm.args>
+      <!-- XXX <java jvm="${profiler.java}" ...> -->
+      <profiler.action>profile</profiler.action>
+    </properties>
+  </action>
+  <action>
+        <actionName>CUSTOM-resume-debug</actionName>
+        <displayName>Resume Debug</displayName>
+        <goals>
+            <goal>antrun:run</goal>
+        </goals>
+        <properties>
+            <vm.args>-Xdebug -Xrunjdwp:transport=dt_socket,server=n,address=${jpda.address}</vm.args>
+            <jpda.listen>true</jpda.listen>
+        </properties>
+    </action>
+</actions>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/website-launcher/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/website-launcher/pom.xml b/provisioning/launchers/website-launcher/pom.xml
new file mode 100644
index 0000000..fb1b4b2
--- /dev/null
+++ b/provisioning/launchers/website-launcher/pom.xml
@@ -0,0 +1,289 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Copyright 2012 Fusepool.eu Project Partners
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+    <modelVersion>4.0.0</modelVersion>
+    <parent>
+        <groupId>org.apache.clerezza</groupId>
+        <artifactId>clerezza</artifactId>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
+    </parent>
+    <groupId>org.apache.clerezza.provisioning</groupId>
+    <artifactId>website-launcher</artifactId>
+    <version>1.0.0-SNAPSHOT</version>
+    <packaging>jar</packaging>
+
+    <name>Clerezza - Provisioning - Launchers - Website Launcher</name>
+    <description>Runnable jar using the clerezza partial bundlelists for 
+        accessing and editing data in the content graph.</description>
+
+    <prerequisites>
+      <maven>3.0.2</maven>
+    </prerequisites>
+    
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-clean-plugin</artifactId>
+                <configuration>
+                    <filesets>
+                        <fileset>
+                            <directory>.</directory>
+                            <includes>
+                                <include>stanbol/**</include>
+                                <include>*.log</include>
+                            </includes>
+                        </fileset>
+                    </filesets>
+                </configuration>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>maven-launchpad-plugin</artifactId>
+                <executions>
+                    <execution>
+                        <id>prepare-package</id>
+                        <goals>
+                            <goal>prepare-package</goal>
+                        </goals>
+                        <configuration>
+                            <includeDefaultBundles>false</includeDefaultBundles>
+                            <!-- Standalone jar requires an OSGi http service implementation -->
+                            <jarWebSupport>
+                                <groupId>org.apache.felix</groupId>
+                                <artifactId>org.apache.felix.http.jetty</artifactId>
+                                <version>2.2.1</version>
+                            </jarWebSupport>
+                        </configuration>
+                    </execution>
+                </executions>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-jar-plugin</artifactId>
+                <configuration>
+                    <archive>
+                        <manifest>
+                            <addClasspath>true</addClasspath>
+                            <mainClass>org.apache.stanbol.launchpad.Main</mainClass>
+                            <addDefaultImplementationEntries>true</addDefaultImplementationEntries>
+                        </manifest>
+                    </archive>
+                </configuration>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-shade-plugin</artifactId>
+                <executions>
+                    <execution>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>shade</goal>
+                        </goals>
+                        <configuration>
+                            <artifactSet>
+                                <!-- Use this to in/exclude only specific dependencies -->
+                                <includes>
+                                    <include>org.apache.stanbol:org.apache.stanbol.commons.launchpad</include>
+                                    <include>org.apache.sling:org.apache.sling.launchpad.base</include>
+                                </includes>
+                            </artifactSet>
+                            <!-- transformers>
+                              <transformer implementation="org.apache.maven.plugins.shade.resource.ComponentsXmlResourceTransformer" />
+                            </transformers -->
+                        </configuration>
+                    </execution>
+                </executions>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.rat</groupId>
+                <artifactId>apache-rat-plugin</artifactId>
+                <configuration>
+                    <excludes />
+                </configuration>
+            </plugin>
+        </plugins>
+        <pluginManagement>
+            <plugins>
+                <plugin>
+                    <groupId>org.apache.sling</groupId>
+                    <artifactId>maven-launchpad-plugin</artifactId>
+                    <version>2.2.0</version>
+                    <extensions>true</extensions>
+                </plugin>
+                <!-- generates version number of dependencies suitable for introspection
+                in pax-exam based OSGi lightweight-integration tests -->
+                <plugin>
+                    <groupId>org.apache.servicemix.tooling</groupId>
+                    <artifactId>depends-maven-plugin</artifactId>
+                    <version>1.0</version>
+                    <executions>
+                        <execution>
+                            <id>generate-depends-file</id>
+                            <goals>
+                                <goal>generate-depends-file</goal>
+                            </goals>
+                        </execution>
+                    </executions>
+                </plugin>
+                <plugin>
+                    <groupId>org.apache.maven.plugins</groupId>
+                    <artifactId>maven-antrun-plugin</artifactId>
+                    <version>1.7</version>
+                    <configuration>
+                        <target>
+                            <property name="vm.args" value="" />
+                            <java fork="true" jar="${project.build.directory}/${project.build.finalName}.jar" dir="${project.build.directory}">
+                                <jvmarg line="-Xmx1024m -XX:MaxPermSize=256M ${vm.args}" />
+                            </java>
+                        </target>
+                    </configuration>
+                </plugin>
+            </plugins>
+        </pluginManagement>
+    </build>
+
+
+    <dependencyManagement>
+        <dependencies>
+            <!-- Sling -->
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.base</artifactId>
+                <version>2.5.0</version>
+                <classifier>app</classifier>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.base</artifactId>
+                <version>2.5.0</version>
+                <classifier>webapp</classifier>
+                <type>war</type>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.installer</artifactId>
+                <version>1.2.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.api</artifactId>
+                <version>1.1.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.installer.api</artifactId>
+                <version>1.0.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.installer.core</artifactId>
+                <version>3.4.6</version>
+            </dependency>
+
+        </dependencies>
+    </dependencyManagement>
+
+
+    <dependencies>
+        <dependency>
+            <!-- The Apache Stanbol launchpad -->
+            <groupId>org.apache.stanbol</groupId>
+            <artifactId>org.apache.stanbol.commons.launchpad</artifactId>
+            <version>0.12.0</version>
+        </dependency>
+        <dependency>
+            <!-- maven-launchpad-plugin builds on the launchpad.base app -->
+            <groupId>org.apache.sling</groupId>
+            <artifactId>org.apache.sling.launchpad.base</artifactId>
+            <classifier>app</classifier>
+        </dependency>
+    
+        <!-- BundeLists -->
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>felixosgi</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>felixweb</artifactId>
+            <version>0.1</version>
+            <type>partialbundlelist</type>
+        </dependency>
+       <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>rdf</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+		
+        <dependency>
+             <groupId>org.apache.clerezza.provisioning</groupId>
+             <artifactId>rdf.tdb</artifactId>
+             <version>1.0.0-SNAPSHOT</version>
+             <type>partialbundlelist</type>
+         </dependency>
+		 
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>platform.graphnodeprovider</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+      <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>jaxrs</artifactId>
+            <version>0.1</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>typehandlerspace</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>typerendering</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>rdf.web</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>platform.content</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>site.tools</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+    </dependencies>
+  
+  
+</project>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/website-launcher/src/main/bundles/list.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/website-launcher/src/main/bundles/list.xml b/provisioning/launchers/website-launcher/src/main/bundles/list.xml
new file mode 100644
index 0000000..1098261
--- /dev/null
+++ b/provisioning/launchers/website-launcher/src/main/bundles/list.xml
@@ -0,0 +1,5 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<bundles>
+    <startLevel level="1">
+    </startLevel>
+</bundles>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/launchers/website-launcher/src/main/config/note.txt
----------------------------------------------------------------------
diff --git a/provisioning/launchers/website-launcher/src/main/config/note.txt b/provisioning/launchers/website-launcher/src/main/config/note.txt
new file mode 100644
index 0000000..eb01c8c
--- /dev/null
+++ b/provisioning/launchers/website-launcher/src/main/config/note.txt
@@ -0,0 +1 @@
+Sling launchpad plugin requires this directory
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/pom.xml b/provisioning/pom.xml
index 9d67a89..a87a7bc 100644
--- a/provisioning/pom.xml
+++ b/provisioning/pom.xml
@@ -55,6 +55,7 @@
         <module>rdf.web</module>
         <module>platform.content</module>
         <module>platform.tools</module>
+        <module>site.tools</module>
         <module>shell</module>
         <module>security</module>
         <module>launchers</module>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/site.tools/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/site.tools/pom.xml b/provisioning/site.tools/pom.xml
new file mode 100644
index 0000000..026437b
--- /dev/null
+++ b/provisioning/site.tools/pom.xml
@@ -0,0 +1,96 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+
+ Licensed to the Apache Software Foundation (ASF) under one
+ or more contributor license agreements.  See the NOTICE file
+ distributed with this work for additional information
+ regarding copyright ownership.  The ASF licenses this file
+ to you under the Apache License, Version 2.0 (the
+ "License"); you may not use this file except in compliance
+ with the License.  You may obtain a copy of the License at
+
+   http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing,
+ software distributed under the License is distributed on an
+ "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ KIND, either express or implied.  See the License for the
+ specific language governing permissions and limitations
+ under the License.
+
+-->
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
+    <modelVersion>4.0.0</modelVersion>
+
+    <parent>
+        <artifactId>clerezza</artifactId>
+        <groupId>org.apache.clerezza</groupId>
+        <version>7-SNAPSHOT</version>
+        <relativePath/>
+    </parent>
+    
+    <groupId>org.apache.clerezza.provisioning</groupId>
+    <artifactId>site.tools</artifactId>
+    <version>1.0.0-SNAPSHOT</version>
+    <packaging>feature</packaging>
+
+    <name>Clerezza - Provisioning - Site Tools</name>
+    <description>A Karaf feature and partialbundlelist with the bundles needed
+        to edit and generate the site.
+    
+        This feature depends on java and OSGi platform libraries (javax.xml,
+        org.osgi.service.cm and others), slf4j logging
+        - rdf
+        - rdf.web
+        - platform.graphnodprovider
+        - typerendering
+        - typehandlerspace
+        - platform.content   
+    </description>
+
+    <dependencies>
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>platform.editor</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>   
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>platform.documentation</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>platform.documentation.viewer</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>    
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>tools.offline</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>rdf.stable.serializer</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>    
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>website</artifactId>
+            <version>0.2-SNAPSHOT</version>
+        </dependency>
+    </dependencies>
+
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.wymiwyg.karaf.tooling</groupId>
+                <artifactId>karaf-sling-maven-plugin</artifactId>
+                <configuration>
+                    <startLevel>26</startLevel>
+                </configuration>
+            </plugin>
+        </plugins>
+    </build>
+    
+</project>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/provisioning/site.tools/src/main/feature/feature.xml
----------------------------------------------------------------------
diff --git a/provisioning/site.tools/src/main/feature/feature.xml b/provisioning/site.tools/src/main/feature/feature.xml
new file mode 100644
index 0000000..9b0f399
--- /dev/null
+++ b/provisioning/site.tools/src/main/feature/feature.xml
@@ -0,0 +1,26 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+
+    Licensed to the Apache Software Foundation (ASF) under one or more
+    contributor license agreements.  See the NOTICE file distributed with
+    this work for additional information regarding copyright ownership.
+    The ASF licenses this file to You under the Apache License, Version 2.0
+    (the "License"); you may not use this file except in compliance with
+    the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
+-->
+<features name="${project.artifactId}-${project.version}" xmlns="http://karaf.apache.org/xmlns/features/v1.0.0">
+
+    <feature name='${project.artifactId}' description='${project.name}' version='${project.version}'>
+        <details>${project.description}</details>
+        <!-- <config>foo=bar</config> -->
+    </feature>
+
+</features>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/report.xml
----------------------------------------------------------------------
diff --git a/report.xml b/report.xml
new file mode 100644
index 0000000..9b0d503
--- /dev/null
+++ b/report.xml
@@ -0,0 +1,35 @@
+<?xml version='1.0' encoding='UTF-8'?>
+<dfxml xmloutputversion='1.0'>
+  <metadata 
+  xmlns='http://afflib.org/tcpflow/' 
+  xmlns:xsi='http://www.w3.org/2001/XMLSchema-instance' 
+  xmlns:dc='http://purl.org/dc/elements/1.1/'>
+    <dc:type>Feature Extraction</dc:type>
+  </metadata>
+  <creator version='1.0'>
+    <program>TCPFLOW</program>
+    <version>1.4.4</version>
+    <build_environment>
+      <compiler>4.8.2 (4.8.2 20140110 (prerelease) [ibm/gcc-4_8-branch merged from gcc-4_8-branch, revision 205847])</compiler>
+      <CPPFLAGS>-pthread -I/usr/local/include -D_FORTIFY_SOURCE=2 -DUTC_OFFSET=+0000 </CPPFLAGS>
+      <CFLAGS>-g   -pthread -g -O3 -fstack-protector --param=ssp-buffer-size=4 -Wformat -Werror=format-security -MD -D_FORTIFY_SOURCE=2 -Wpointer-arith -Wmissing-declarations -Wmissing-prototypes -Wshadow -Wwrite-strings -Wcast-align -Waggregate-return -Wbad-function-cast -Wcast-qual -Wundef -Wredundant-decls -Wdisabled-optimization -Wfloat-equal -Wmultichar -Wc++-compat -Wmissing-noreturn -Wall -Wstrict-prototypes</CFLAGS>
+      <CXXFLAGS>-g -pthread -g -O3 -fstack-protector --param=ssp-buffer-size=4 -Wformat -Werror=format-security -std=c++11 -Wall -MD -D_FORTIFY_SOURCE=2 -Wpointer-arith -Wshadow -Wwrite-strings -Wcast-align -Wredundant-decls -Wdisabled-optimization -Wfloat-equal -Wmultichar -Wmissing-noreturn -Woverloaded-virtual -Wsign-promo -funit-at-a-time -Wstrict-null-sentinel -Weffc++ </CXXFLAGS>
+      <LDFLAGS>-L/usr/local/lib -Wl,-Bsymbolic-functions -Wl,-z,relro</LDFLAGS>
+      <LIBS>-lpcap -lcairo -lfontconfig -lfreetype -lpixman-1 -lexpat  -lssl -lcrypto -lz -lssl -lcrypto </LIBS>
+      <compilation_date>2014-01-13T17:14:40</compilation_date>
+      <library name="boost" version="105400"/>
+    </build_environment>
+    <execution_environment>
+      <os_sysname>Linux</os_sysname>
+      <os_release>3.13.0-52-generic</os_release>
+      <os_version>#86-Ubuntu SMP Mon May 4 04:32:59 UTC 2015</os_version>
+      <host>5033e1dfa905</host>
+      <arch>x86_64</arch>
+      <command_line>tcpflow -c port 8080 -i lo</command_line>
+      <uid>0</uid>
+      <start_time>2015-05-18T11:19:57Z</start_time>
+    </execution_environment>
+  </creator>
+  <configuration>
+  </configuration>
+  <tdelta>0</tdelta>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/site/readme.txt
----------------------------------------------------------------------
diff --git a/site/readme.txt b/site/readme.txt
index 7ce9384..83e96c2 100644
--- a/site/readme.txt
+++ b/site/readme.txt
@@ -1,12 +1,12 @@
 Editing and deploying the clerezza website
 
-- start clerezza on localhost:8080
+- start the webiste luancher, provisioning/launchers/website-launcher
 
-- install the directory with the site project (the directory containing this readme) with: Dev load LocationSpec("/path/to/apache/clerezza/trunk/site", noFastUpdate)
+- Go to http://localhost:8080/graph/upload-form and upload graph.nt to the content graph
 
-- you'll now see the contents of the clerezza site on your local instance, the content-graph is regularly written to the graph.nt file
+- change the site as needed, do not create pages ending with /, create a page ending with /index instead, the entry page is http://localhost:8080/index (you may add "?mode=edit" to edit a page)
 
-- change the site as needed, do not create pages ending with /, create a page ending with /index instead, the entry page is http://localhost:8080/index (you may open http://localhost:8080/tools/editor with firefox to edit it)
+- retrieve the modified graph: curl 'http://localhost:8080/graph?name=urn%3Ax-localinstance%3A%2Fcontent.graph' -H 'Accept: application/n-triples' > graph.nt
 
 - commit the changed graph.nt to version control
diff --git a/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/UriMutatorIterator.java b/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/UriMutatorIterator.java
index c728a76..d206af3 100644
--- a/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/UriMutatorIterator.java
+++ b/platform/documentation/src/main/java/org/apache/clerezza/platform/documentation/UriMutatorIterator.java
@@ -37,18 +37,18 @@ import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.apache.clerezza.rdf.core.NonLiteral;
-import org.apache.clerezza.rdf.core.Resource;
-import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.TypedLiteral;
-import org.apache.clerezza.rdf.core.UriRef;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
-import org.apache.clerezza.rdf.core.impl.TypedLiteralImpl;
+import org.apache.clerezza.commons.rdf.BlankNodeOrIRI;
+import org.apache.clerezza.commons.rdf.RDFTerm;
+import org.apache.clerezza.commons.rdf.Triple;
+import org.apache.clerezza.commons.rdf.IRI;
+import org.apache.clerezza.commons.rdf.Literal;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
+import org.apache.clerezza.commons.rdf.impl.utils.TypedLiteralImpl;
 import org.w3c.dom.Document;
 import org.xml.sax.SAXException;
 
 /**
  * Replaces the <code>BASE_URI_PLACEHOLDER</code> in the <code>UriRef</code>s 
  * as well as in the XML Literal of the <code>Triple</code>s provided by the
  * specified <code>Iterator</code>s with the specified base URI.
  *
@@ -60,8 +60,8 @@ public class UriMutatorIterator implements Iterator<Triple> {
 
     private DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
 
-    public static final UriRef XML_LITERAL =
-            new UriRef("http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral");
+    public static final IRI XML_LITERAL =
+            new IRI("http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral");
 
     public static final String BASE_URI_PLACEHOLDER = "bundle://";
     private Iterator<Triple> wrapped;
@@ -87,17 +87,17 @@ public class UriMutatorIterator implements Iterator<Triple> {
     public Triple next() {
         Triple triple = wrapped.next();
 
-        NonLiteral subject = triple.getSubject();
-        if (subject instanceof UriRef) {
-            subject = replacePlaceHolder((UriRef) subject);
+        BlankNodeOrIRI subject = triple.getSubject();
+        if (subject instanceof IRI) {
+            subject = replacePlaceHolder((IRI) subject);
         }
-        UriRef predicate = replacePlaceHolder(triple.getPredicate());
+        IRI predicate = replacePlaceHolder(triple.getPredicate());
 
-        Resource object = triple.getObject();
-        if (object instanceof UriRef) {
-            object = replacePlaceHolder((UriRef) object);
-        } else if (object instanceof TypedLiteral) {
-            TypedLiteral literal = (TypedLiteral) object;
+        RDFTerm object = triple.getObject();
+        if (object instanceof IRI) {
+            object = replacePlaceHolder((IRI) object);
+        } else if (object instanceof Literal) {
+            Literal literal = (Literal) object;
             if (literal.getDataType().equals(XML_LITERAL)) {
                 object = replacePlaceHolderInUrl(literal);
             }
@@ -110,7 +110,7 @@ public class UriMutatorIterator implements Iterator<Triple> {
         throw new UnsupportedOperationException("Not supported.");
     }
 
-    private UriRef replacePlaceHolder(UriRef uriRef) {
+    private IRI replacePlaceHolder(IRI uriRef) {
         String orig = uriRef.getUnicodeString();
         if (orig.startsWith(BASE_URI_PLACEHOLDER)) {
             int nextSlash = orig.indexOf("/", BASE_URI_PLACEHOLDER.length());
@@ -121,13 +121,13 @@ public class UriMutatorIterator implements Iterator<Triple> {
             } else {
                 bundleSymbolicName = originBundleSymbName;
             }
-            return new UriRef(baseUri + "bundle-doc/" + bundleSymbolicName +
+            return new IRI(baseUri + "bundle-doc/" + bundleSymbolicName +
                     orig.substring(nextSlash));
         }
         return uriRef;
     }
 
-    private TypedLiteral replacePlaceHolderInUrl(TypedLiteral xmlLiteral) {
+    private Literal replacePlaceHolderInUrl(Literal xmlLiteral) {
         final String tagName = "infoBit";
         final String openingTag = "<" + tagName + ">";
         final String closingTag = "</" + tagName + ">";

http://git-wip-us.apache.org/repos/asf/clerezza/blob/fe6530be/platform/documentation/src/test/java/org/apache/clerezza/platform/documentation/UriMutatorIteratorTest.java
----------------------------------------------------------------------
@@ -37,18 +37,18 @@ import javax.xml.transform.stream.StreamResult;
 
 /**
- * Replaces the <code>BASE_URI_PLACEHOLDER</code> in the <code>UriRef</code>s 
+ * Replaces the <code>BASE_URI_PLACEHOLDER</code> in the <code>IRI</code>s 
  * as well as in the XML Literal of the <code>Triple</code>s provided by the
  * specified <code>Iterator</code>s with the specified base URI.